#define _GNU_SOURCE
#include "nfs_config.h"

#include <stdio.h>
#include <fcntl.h>
#include <unistd.h>
#include <ctype.h>
#include <string.h>
#include <stdlib.h>
#include <syslog.h>
#include <glib/gi18n.h>


#define CONFIG_PATH "/etc/disk_check.conf"


disk_config config;

static void process_config(FILE * cfg)
{
	char *line_buf = NULL;
	size_t len = 0;

	while (getline(&line_buf, &len, cfg) > 0) {
		char *buffer = line_buf;
		while (isspace(*buffer))
			buffer++;
		if (buffer[0] == '#')
			continue;
		int l = strlen(buffer) - 1;
		if (l <= 0)
			continue;
		buffer[l] = 0;

        char *key = strsep(&buffer, "=");
        while (isspace(*buffer))
			buffer++;
        
        if (!strncmp(key, "setReservedToZero", strlen("setReservedToZero")) && !strncmp(buffer, "no", 2)) {
            config.set_reserved_to_zero = 0;
        } else {
            config.set_reserved_to_zero = 1;
        }
        if (!strncmp(key, "size", strlen("size"))) {
            config.size = strndup(buffer, strlen(buffer));
        }
        printf("key = %s, value = %s\n", key, buffer);
	}
    config.initialized = 1;
	free(line_buf);
}

void rewrite_config() {
    if (!config.initialized) {
        return;
    }
    FILE *cfg = fopen(CONFIG_PATH"-", "w");
    if (!cfg){
		perror(CONFIG_PATH);
        return;
	}
    fprintf(cfg, "%s=%s\n", "setReservedToZero", config.set_reserved_to_zero ? "yes": "no");
    if (config.size) {
        fprintf(cfg, "%s=%s\n", "size", config.size);
    }
    

    fflush(cfg);
    fclose(cfg);
    rename(CONFIG_PATH"-", CONFIG_PATH);
}

disk_config_p read_conf() {
	FILE *cfg = fopen(CONFIG_PATH, "r");
	if (!cfg){
		perror(CONFIG_PATH);
        return NULL;
	}

    process_config(cfg);

	fclose(cfg);
	return &config;
}